pub struct DiagSpan {
pub start: usize,
pub end: usize,
}Expand description
A byte range used to point at source text in a diagnostic
Every diagnostic has a severity, a short code (e.g. “E001”), and a message.
Below - mirrors Span in oxyl-lexer but lives here so that the diagnostics
stay independent of the lexer crate. Will keep the two types in sync
manually for now; will unify when the crate graph is refactored,
Fields
start: usizeend: usizeImplementations